@@ -4,11 +4,11 @@
 #' All classes in this package are virtual and need to be extended by
 #' the various R/DBMS implementations (so-called *DBI backends*).
 #'
-#' @inheritSection DBItest::DBIspec Definition
-#' @inheritSection DBItest::DBIspec DBI classes and methods
-#' @inheritSection DBItest::DBIspec Construction of the DBIDriver object
+#' @inheritSection DBItest::spec_getting_started Definition
+#' @inheritSection DBItest::spec_compliance_methods DBI classes and methods
+#' @inheritSection DBItest::spec_driver_constructor Construction of the DBIDriver object
 #'
-#' @examples
+#' @examplesIf requireNamespace("RSQLite", quietly = TRUE)
 #' RSQLite::SQLite()
 #' @seealso
 #'   Important generics: [dbConnect()], [dbGetQuery()],
@@ -17,3 +17,14 @@
 #'   Formal specification (currently work in progress and incomplete):
 #'   `vignette("spec", package = "DBI")`
 "_PACKAGE"
+
+has_arrow <- function() {
+  requireNamespace("nanoarrow", quietly = TRUE)
+}
+
+require_arrow <- function() {
+  if (has_arrow()) {
+    return(invisible(TRUE))
+  }
+  stop("The nanoarrow package is required for this functionality.")
+}
