@@ -1,7 +1,12 @@
+## ----echo = FALSE-------------------------------------------------------------
+knitr::opts_chunk$set(
+  echo = FALSE,
+  eval = requireNamespace("magrittr", quietly = TRUE) && requireNamespace("xml2", quietly = TRUE)
+)
+
 ## ----echo = FALSE-------------------------------------------------------------
 library(magrittr)
 library(xml2)
-knitr::opts_chunk$set(echo = FALSE)
 r <- rprojroot::is_r_package$make_fix_file()
 
 ## ----error=TRUE---------------------------------------------------------------
@@ -15,7 +20,7 @@ html_topic <- function(name) {
   conn <- textConnection(NULL, "w")
   on.exit(close(conn))
 
-  #tools::Rd2HTML(rd, conn, Links = Links)
+  # tools::Rd2HTML(rd, conn, Links = Links)
   tools::Rd2HTML(rd, conn)
 
   textConnectionValue(conn)
@@ -50,7 +55,7 @@ patch_package_doc <- function(x) {
 }
 
 move_contents_of_usage_section <- function(x) {
-  # http://stackoverflow.com/a/3839299/946850
+  # https://stackoverflow.com/a/3839299/946850
   usage_contents <-
     x %>%
     xml_find_all(
@@ -58,7 +63,7 @@ move_contents_of_usage_section <- function(x) {
 
   usage_text <-
     usage_contents %>%
-    xml_find_first("//pre") %>% 
+    xml_find_first("//pre") %>%
     xml_text
 
   h3 <- x %>% xml_find_first("//h3")
@@ -82,7 +87,7 @@ move_contents_of_usage_section <- function(x) {
 }
 
 move_additional_arguments_section <- function(x) {
-  # http://stackoverflow.com/a/3839299/946850 and some trial and error
+  # https://stackoverflow.com/a/3839299/946850 and some trial and error
   additional_arguments <- x %>%
     xml_find_all(
       "//h3[.='Additional arguments'] | //h3[.='Additional arguments']/following-sibling::node()[following-sibling::h3]")
@@ -95,7 +100,7 @@ move_additional_arguments_section <- function(x) {
 }
 
 remove_see_also_section <- function(x) {
-  # http://stackoverflow.com/a/3839299/946850 and some trial and error
+  # https://stackoverflow.com/a/3839299/946850 and some trial and error
   x %>%
     xml_find_all(
       "//h3[.='See Also'] | //h3[.='See Also']/following-sibling::node()[following-sibling::h3]") %>%
@@ -104,7 +109,7 @@ remove_see_also_section <- function(x) {
 }
 
 remove_authors_section <- function(x) {
-  # http://stackoverflow.com/a/3839299/946850 and some trial and error
+  # https://stackoverflow.com/a/3839299/946850 and some trial and error
   x %>%
     xml_find_all(
       "//h3[.='Author(s)'] | //h3[.='Author(s)']/following-sibling::node()[following-sibling::h3]") %>%
@@ -156,10 +161,10 @@ html <- c(
 temp_html <- tempfile(fileext = ".html")
 temp_md <- tempfile(fileext = ".md")
 
-#temp_html <- "out.html"
-#temp_md <- "out.md"
+# temp_html <- "out.html"
+# temp_md <- "out.md"
 
-#html <- '<html><body><pre class="r">\na\nb\n</pre></body></html>'
+# html <- '<html><body><pre class="r">\na\nb\n</pre></body></html>'
 
 writeLines(html, temp_html)
 rmarkdown::pandoc_convert(temp_html, "gfm", verbose = FALSE, output = temp_md)
